@@ -23,4 +23,4 @@ class ControlReceive(HeavyObject):
 
     @classmethod
     def get_C_onMessage(clazz, obj_type, obj_id, inlet_index, args):
-        return ["cReceive_{0}_sendMessage(_c, 0, m);".format(obj_id)]
+        return [f"cReceive_{obj_id}_sendMessage(_c, 0, m);"]
